% getdata	

% [csample,cexact]=getdata(truefn,kernfn,xsample,tsample,params,interval,noise)

% This routine calculates the sample concentration for the
% given (x,t) pairs, based on the user-supplied kernel function.
%
% Inputs
%	truefn		name of matlab function that calculates the
%				true source history 
%				This function is called with the
%				following command:
%					y=truefn(t)
%	kernfn		name of matlab function that calculates the
%				value of the kernel 
%				This function is called with the
%				following command:
%					y=kernfn(xx,tt,params)
%				where xx is a location and tt is a time
%	xsample		array containing sampling locations
%	tsample		time of sampling
%	params		array of all parameters values
%	interval	number of discretizations to use in the numerical
%				integration to calculate sampled concentrations
%
% Outputs
%	csample		array containing the sample concentrations

function [csample,cexact]=...
		getdata(truefn,kernfn,xsample,tsample,params,interval,noise);

% calculate counters
ns=size(xsample,2);

% create the concentration vector
cexact=zeros(ns,1);

% for each x, integrate over time

T=linspace(tsample,0,interval+1);
T=T(1:interval);
deltat=T(1)-T(2);
for j=1:ns
	f=feval(kernfn,xsample(j),T,params);
	f=f.*feval(truefn,fliplr(T));
	cexact(j)=simpson(0,tsample,interval,f);
end	

if noise > 0 
	csample=cexact+randn(ns,1)*noise;
else
	csample=cexact.*(ones(ns,1)+randn(ns,1)*abs(noise));
end

return


